summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/property.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/koproperty/property.h')
-rw-r--r--lib/koproperty/property.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/koproperty/property.h b/lib/koproperty/property.h
index bc8a503e..5f61ff6b 100644
--- a/lib/koproperty/property.h
+++ b/lib/koproperty/property.h
@@ -306,9 +306,9 @@ class KOPROPERTY_EXPORT Property
/*! \return property icon's string. Can be empty. */
TQString icon() const;
- /*! \return a list of all tqchildren for this property, or NULL of there
- is no tqchildren for this property */
- const TQValueList<Property*>* tqchildren() const;
+ /*! \return a list of all children for this property, or NULL of there
+ is no children for this property */
+ const TQValueList<Property*>* children() const;
/*! \return a child property for \a name, or NULL if there is no property with that name. */
Property* child(const TQCString &name);
@@ -407,7 +407,7 @@ class KOPROPERTY_EXPORT Property
protected:
/*! Adds \a prop as a child of this property.
- The tqchildren will be owned by this property. */
+ The children will be owned by this property. */
void addChild(Property *prop);
/*! Adds \a set to this property. */